log('scheduler started');

const AUTO = ' [Авто]';
const MONTH = 'month';
const SET_DAY = 'set_day';
const SET_ENABLED = 'set_enabled';
const STATUS = 'status';
const GET_TRIGGERS = 'get_triggers';
const GET_TRIGGER_DIV = 'get_trigger_div';
const GET_ACTION_DIV = 'get_action_div';
const SET_TIME = 'set_time';
const SET_ACTION = 'set_action';
const REMOVE_TRIGGER = 'remove_trigger';
const REMOVE_ACTION = 'remove_action';

var locationId = null;
var actions = [];
var trigger_content = null;
var action_content = null;

function ready() {
    window.onresize = onResize;
    onResize();

    request(GET_TRIGGER_DIV, function (content) {
        trigger_content = content;
        request(GET_ACTION_DIV, function (content) {
            action_content = content;
            nextMonth();
            onSelect();
        }, null, null);
    }, null, null);
}

function nextMonth(m, y) {
    var url = MONTH;
    if (m&&y) {
        url = [url, m, y].join('/');
    }

    request(url,
        function(content) {
            var div = document.createElement('div');
            div.innerHTML = content;
            const parent = document.getElementById('calendar');
            if (parent.getElementsByClassName('r')[0]) {
                parent.getElementsByClassName('r')[0].remove();
            }
            parent.appendChild(div);
        }, null, null);
}

function changeDay(event, y, m, d) {
    const target = event.currentTarget;
    request(SET_DAY,
        function (response) {
            target.className = response
        },
        function () {
            shake(target);
        },
        {year: y, month: m, day: d}
    );
}

function onSelect() {
    const selector = document.getElementById('selector');
    locationId = selector.options[selector.selectedIndex].id;

    request(STATUS,
        function (response) {
            actions = response.actions;
            setToggle(response.enabled);
            drawActions();
        },
        null,
        {id: locationId}
    );
}

function onTabClick(e) {
    const target = e.target.tagName === 'BUTTON' ? e.target.parentElement : e.target;
    const collection = document.getElementsByClassName('panel-selected-td');
    for (var i = 0; i < collection.length; i++) {
        if (collection[i] === target) {
            return;
        }
        collection[i].className = 'panel-not-selected-td';
    }

    target.className = 'panel-selected-td';

    drawActions();
}

function drawActions() {
    const dayType = document.getElementsByClassName('panel-selected-td')[0].id;
    const table = document.getElementsByClassName('panel-table')[0];
    var rows = table.children[0];
    while (rows.childElementCount > 2) {
        rows.children[1].remove();
    }

    request(GET_TRIGGERS,
        function (content) {
            content = content.sort(function (a, b) {
                return a.time.localeCompare(b.time);
            });
            for (var i=0; i < content.length; i++) {
                var trigger = createTrigger(
                    table.insertRow(table.rows.length - 1),
                    content[i]
                );

                for (var j=0; j < content[i].actions.length; j++) {
                    var a_table = trigger.getElementsByClassName('b')[0];
                    createAction(
                        a_table.insertRow(a_table.rows.length - 1),
                        content[i].actions[j]
                    );
                }
            }
        },
        null,
        {id: locationId, trigger: dayType}
    );
}

function onToggleHelper(e) {
    const slider = document.getElementById("autocheckbox");
    slider.checked = !slider.checked;
    onToggle({target: slider});
}

function setToggle(enabled) {
    document.getElementsByClassName('panel-table')[0].hidden = !enabled;
    document.getElementById('autocheckbox').checked = enabled;
    const selector = document.getElementById('selector');
    const option = selector.options[selector.selectedIndex];

    if (enabled) {
        if (option.textContent.indexOf(AUTO) === -1) {
            option.textContent += AUTO;
        }
    } else {
        if (option.textContent.indexOf(AUTO) !== -1) {
            option.textContent = option.textContent.substring(0, option.textContent.indexOf(AUTO));
        }
    }
}

function onToggle(e) {
    const enabled = e.target.checked;
    request(
        SET_ENABLED,
        function () {
            setToggle(enabled);
        },
        function (e) {
            setToggle(!enabled);
        },
        {id: locationId, enabled: enabled}
    );
}

function createTrigger(row, data) {
    var div = document.createElement('td');
    div.className = "panel-td";
    div.setAttribute('colspan', '2');
    div.innerHTML = trigger_content;
    if (data !== undefined) {
        div.getElementsByClassName('shcedule-time')[0].value = data.time;
        row.setAttribute('trigger-id', data.id);
        row.setAttribute('trigger-time', data.time);
    }

    row.appendChild(div);

    return div;
}

function addAction(e) {
    const table = $(e).closest('table')[0];
    const timeDiv = $(table).find('.shcedule-time')[0];
    if (!timeDiv.value) {
        shake(timeDiv);
    } else if (!$(timeDiv).closest(' table').closest(' tr')[0].getAttribute('trigger-id')) {
        shake($(timeDiv.form).find( 'input[name=commit]')[0]);
    } else {
        createAction(table.insertRow(table.rows.length - 1));
    }
}

function removeAction(e) {
    const row = $(e).closest('tr')[0];
    if (row.hasAttribute('action-id')) {
        request(REMOVE_ACTION,
            function () {
                destroy(row);
            },
            function () {
                shake(e);
            },
            {
                location: locationId,
                trigger: $(row).closest('td').closest('tr')[0].getAttribute('trigger-id'),
                action: row.getAttribute('action-id')
            });
    }
    else {
        destroy(row);
    }
}

function addTrigger(e) {
    const table = $(e).closest('td').closest('table')[0];
    const triggerDiv = createTrigger(
        table.insertRow(table.rows.length - 1)
    );
}

function removeTrigger(e) {
    const table = $(e).closest('table')[0];
    const row = $(table).closest('tr')[0];
    if (row.hasAttribute('trigger-id')) {
        request(REMOVE_TRIGGER,
            function () {
                destroy(table);
            },
            function () {
                shake(e);
            },
            {
                location: locationId,
                trigger: row.getAttribute('trigger-id')
            }
        );
    }
    else {
        destroy(table);
    }
}

function createAction(cell, data) {
    cell.innerHTML = action_content;
    cell.className = [cell.className, 'animated-destroy'].join(' ');
    var targetSelector = cell.getElementsByClassName('shcedule-select target')[0];

    const targets = Object.keys(actions);
    for (var i=0; i < targets.length; i++) {
        var opt = document.createElement('option');
        opt.textContent = targets[i];
        targetSelector.appendChild(opt);
    }

    if (data !== undefined) {
        cell.setAttribute('action-id', data.id);
        targetSelector.selectedIndex = data.target+1;
    }
    else {
        shake(targetSelector);
    }

    onSelectTarget(targetSelector, data);
}

function onSelectTarget(targetSelector, data) {
    const row = $(targetSelector).closest('tr')[0];
    const tIndex = targetSelector.selectedIndex - 1;
    const commandSelector = $(row).find('.command')[0];
    var options = commandSelector.getElementsByTagName('option');
    while (options.length > 1) {
        options[1].remove();
    }

    if (tIndex > -1) {
        const targets = Object.keys(actions);
        for (var i = 0; i < actions[targets[tIndex]].length; i++) {
            var opt = document.createElement('option');
            opt.textContent = actions[targets[tIndex]][i].name;
            commandSelector.appendChild(opt);
        }

        row.setAttribute('action-target', tIndex);
    }

    if (data !== undefined) {
        commandSelector.selectedIndex = data.action + 1;
        row.setAttribute('action-command', commandSelector.selectedIndex);
        onSelectCommand(commandSelector, data);
    }
    else {
        commandSelector.selectedIndex = 0;
        shake(commandSelector);
        $(row).find('.shcedule-input')[0].hidden = true;
        $(row).find('.value')[0].hidden = true;
    }
}

function onSelectCommand(commandSelector, data) {
    const row = $(commandSelector).closest('tr')[0];
    const cIndex = commandSelector.selectedIndex-1;
    const targetSelector = $(row).find('.target')[0];
    const valueSelector = $(row).find('.value')[0];
    const valueInput = $(row).find('.shcedule-input')[0];
    const targets = Object.keys(actions);
    const values = actions[targets[targetSelector.selectedIndex-1]][cIndex].values;
    if (values === undefined) {
        valueSelector.hidden = true;
        valueInput.hidden = false;
        onValueChanged(valueInput, data);
    }
    else if (values.length > 1) {
        valueSelector.hidden = false;
        valueInput.hidden = true;

        var options = valueSelector.getElementsByTagName('option');
        while (options.length > 1) {
            options[1].remove();
        }

        for (var i=0; i < values.length; i++) {
            var opt = document.createElement('option');
            opt.textContent = values[i];
            valueSelector.appendChild(opt);
        }

        if (data !== undefined) {
            valueSelector.selectedIndex = data.value + 1;
            onSelectValue(valueSelector, data);
        }
        else {
            valueSelector.selectedIndex = 0;
            shake(valueSelector);
        }
    }
    else {
        valueSelector.hidden = true;
        valueInput.hidden = true;

        if (data === undefined) {
            request(SET_ACTION,
                function (response) {
                    row.setAttribute('action-id', response);
                    row.setAttribute('action-command', cIndex);
                },
                function (error, data) {
                    commandSelector.selectedIndex = row.getAttribute('action-command');
                    shake(row);
                },
                {
                    location: locationId,
                    target: targetSelector.selectedIndex - 1,
                    trigger: $(row).closest('table').closest('tr')[0].getAttribute('trigger-id'),
                    action: row.getAttribute('action-id'),
                    index: cIndex
                });
        }
    }
}

function onValueChanged(valueInput, data) {
    const row = $(valueInput).closest('tr')[0];
    const targetSelector = $(row).find('.target')[0];
    const commandSelector = $(row).find('.command')[0];

    if (data !== undefined) {
        valueInput.value = data.value;
    }
    else if (valueInput.value !== row.getAttribute('action-value'))  {
        if (valueInput.value) {
            request(SET_ACTION,
                function (response) {
                    row.setAttribute('action-id', response);
                    row.setAttribute('action-value', valueInput.value);
                },
                function (error, data) {
                    valueInput.value = row.getAttribute('action-value');
                    shake(row);
                },
                {
                    location: locationId,
                    target: targetSelector.selectedIndex - 1,
                    trigger: $(row).closest('table').closest('tr')[0].getAttribute('trigger-id'),
                    action: row.getAttribute('action-id'),
                    index: commandSelector.selectedIndex-1,
                    value: valueInput.value
                });
        }
    }
}

function onSelectValue(valueSelector, data) {
    const row = $(valueSelector).closest('tr')[0];
    const targetSelector = $(row).find('.target')[0];
    const commandSelector = $(row).find('.command')[0];

    if (data !== undefined) {
        valueSelector.selectedIndex = data.value+1;
        row.setAttribute('action-value-index', data.value+1);
    }
    else {
        request(SET_ACTION,
            function (response) {
                row.setAttribute('action-id', response);
                row.setAttribute('action-value-index', valueSelector.selectedIndex-1);
            },
            function (error, data) {
                valueSelector.selectedIndex = row.getAttribute('action-value-index');
                shake(row);
            },
            {
                location: locationId,
                target: targetSelector.selectedIndex - 1,
                trigger: $(row).closest('table').closest('tr')[0].getAttribute('trigger-id'),
                action: row.getAttribute('action-id'),
                index: commandSelector.selectedIndex-1,
                value: valueSelector.selectedIndex-1
            });
    }
}

function destroy(element) {
    element.style.opacity = 0;
    element.addEventListener('transitionend', function () {
        $(element).closest('tr').remove();
    });
}

function onResize() {
    var zoom = document.body.clientWidth/1250;
    if (zoom > 0.9) {
        zoom = 0.9;
    }
    $(".parent").css({zoom: zoom});
}

function onTimeChanged(e) {
    const triggerTime = $(e.form).closest(' tr')[0].getAttribute('trigger-time');
    if (e.value) {
        $(e.form).find('input[name=commit]')[0].hidden = e.value === triggerTime;
    }
}

function commitTime(e) {
    const row = $(e.form).closest(' tr')[0];
    e.hidden = true;

    request(SET_TIME,
        function (response) {
            row.setAttribute('trigger-id', response.id);
            row.setAttribute('trigger-time', e.form.time.value);
        },
        function () {
            const timeInput = $(e.form).find('input[type=time]')[0];
            timeInput.value = row.getAttribute('trigger-time');
            shake(timeInput);
        },
        {
            location: locationId,
            trigger: row.getAttribute('trigger-id'),
            type: document.getElementsByClassName('panel-selected-td')[0].id,
            time: e.form.time.value
        }
    );
}