import threading

from spread_core.protocols.dali.gear import general as gear
from .providers import lights


class TunerLimited:
    def __init__(self, owner):
        self._owner = owner
        self._cmd = None
        self.timer = None
        self.speed = 0.1
        self.count = 0
        self._paused = False
        self._delay = 0

    def set_direction(self, cmd, speed):
        self._cmd = cmd
        self.speed = speed
        self.count = 0
        self.set_tunned_flag_for_not_device(True)

        self._start_timer(self._owner.fadeTime)

    def check_state(self, cmd):
        if self._cmd is None:
            self._stop_timer()

        elif isinstance(cmd, (gear.StepUp, gear.StepDown, gear.OnAndStepUp, gear.StepDownAndOff)):
            _c_level = self._owner.get_value(lights.CurrentLevelRaw, 0)
            _c_min = self._owner.get_value(lights.MinLevelRaw, 1)
            _c_max = self._owner.get_value(lights.MaxLevelRaw, 254)

            if self.count not in range(0, 255):
                self.stop()
            elif isinstance(cmd, (gear.StepUp, gear.OnAndStepUp)) and self._owner.is_device and _c_level+1 not in range(_c_min, _c_max+1):
                self.stop()
            elif isinstance(cmd, (gear.StepDown, gear.StepDownAndOff)) and self._owner.is_device and _c_level-1 not in range(_c_min, _c_max+1):
                self.stop()
            elif self.timer is None or not self.timer.is_alive():
                self._start_timer(self.speed, True)

        else:
            self._start_timer(self._owner.fadeTime)

    def step(self):
        if self._cmd is not None:
            cmd = self._cmd
            if cmd is not None:
                if self._delay > 0:
                    self._start_timer(self._delay)
                    self._delay = 0
                else:
                    self._paused = False
                    self._owner.on_command_prepared(cmd, is_tuner=True)

    def stop(self):
        self._cmd = None
        self._delay = 0
        self._owner.set_value(lights.Tuning, 0)
        self._stop_timer()
        self.set_tunned_flag_for_not_device(False)

    def _start_timer(self, delay, incement_count=False):
        self._stop_timer()
        self.timer = threading.Timer(delay, self.step)
        self.timer.setName('TunerStep Timer')
        self.timer.start()
        if incement_count:
            self.count += 1

    def _stop_timer(self):
        if self.timer:
            if self.timer.is_alive():
                self.timer.cancel()
            self.timer = None

    def set_tunned_flag_for_not_device(self, flag):
        _p_ids = []
        if self._owner.is_group:
            _p_ids = self._owner.get_group_members()
        elif self._owner.is_broadcast:
            _p_ids = self._owner.get_broadcast_members()

        for _p_id in _p_ids:
            _provider = self._owner.manager.get_provider(_p_id)
            if isinstance(_provider, self._owner.__class__):
                _provider.is_unaddress_tunned = flag

    def set_pause(self, delay: float):
        self._paused = True
        self._delay = delay

    @property
    def is_active(self): return not self._paused and self._cmd is not None
