from spread_core.mqtt.spread.topic import State
from spread_core.mqtt.spread.variable import Variable
from .enginery import Enginery, _EngineryFunit


class Light(Enginery):
    def __init__(self, p_id, data):
        super(Light, self).__init__(p_id, data)
        self.power = data.get('attributes', {}).get('power', 0)

    def on_state(self, topic: State, variable: Variable):
        super(Light, self).on_state(topic, variable)

        if topic.entity_address.funit_type == BrightnessLevel:
            self.publish_state(On, None if variable.invalid else variable.value > 0)
            for _subginery in self._subgineries:
                _subginery.on_level_changed(eng=self, level=None if variable.invalid else variable.value)
            self.publish_state(PowerLevel, None if variable.invalid else int(self.power * variable.value / 100), delay=PowerLevel.delay)


class SwitchingLight(Light):
    pass


class DimmingLight(Light):
    pass


class TunableWhiteLight(Light):
    pass


class RgbLight(Light):
    pass


class DynamicLight(Light):
    pass


class _LightFunit(_EngineryFunit):
    entity_type = Light


Light.funit_class = _LightFunit


class On(_LightFunit):
    @property
    def set_value(self): return 100 if self._variable.value else 0

    def set(self): self.entity.publish_provider_command(BrightnessLevel, self.set_value)


class BrightnessLevel(_LightFunit):
    pass


class PowerLevel(_LightFunit):
    delay = 0
    def set(self): raise self.NotImplemented()


class GroupLevel(_LightFunit):
    pass


class Temperature(_LightFunit):
    entity_type = TunableWhiteLight
