import json
import logging
import os

from spread_core.errors.project_errors import InitError
from spread_core.tools import manager_interface


class Handler(manager_interface.ManagerOfBroker):
    triggers_path = None

    def __init__(self, project_id, _mqttc):
        self.stopped = False
        super(Handler, self).__init__(_mqttc)
        self.project_id = project_id
        self.triggers = {}

    def parse(self, data):
        raise NotImplementedError()

    def start(self):
        if os.path.isfile(self.triggers_path):
            with open(self.triggers_path, 'r') as file:
                data = file.read()
            if not data:
                data = '[]'
            try:
                data = json.loads(data)
            except BaseException as ex:
                raise InitError(f'Ошибка парсинга файла "{self.triggers_path}": {ex}')
            self.parse(data)
            self.on_ready()
        else:
            raise InitError(f'{self.triggers_path} не существует!')

    def on_ready(self):
        pass

    def on_message(self, topic, variable):
        pass

    def on_exit(self):
        super(Handler, self).on_exit()
        self.stopped = True
        if self.mqttc:
            try:
                self.mqttc.disconnect()
                self.mqttc.loop_stop(True)
            except BaseException as ex:
                logging.error(ex)
