import spread_core.mqtt as mqtt
import spread_core.protocols.dali as dali
from spread_core.bam.dali.managers import Dali
from spread_core.errors.project_errors import ClassifierError, InitError
from spread_core.tools.service_launcher import Launcher
from spread_core.tools.settings import *


class DaliManagerLauncher(Launcher):

    @property
    def manager(self):
        if self._manager is None:
            self._manager = Dali(self.project_id, self.manager_id)
            self._manager.set_broker(
                mqttc=self.mqttc,
                send_interface=self.generate_interface()
            )
        return self._manager

    def generate_interface(self):
        if config.get(LOCAL_ADAPTER, False):
            return dali.driver.dali_interface.DaliCanAdapter(config.get(COMMUNICATE_TIMEOUT, 1))
        else:
            return dali.driver.dali_interface.BrokerAdapter(self.mqttc, config.get(COMMUNICATE_TIMEOUT, 1))

    def on_message(self, mosq, obj, msg):
        super(DaliManagerLauncher, self).on_message(mosq, obj, msg)
        try:
            topic = mqtt.of(msg.topic)
            payload = msg.payload.decode()
            if isinstance(topic, mqtt.bus.TopicBus) and topic.is_dump:
                self._manager.send_interface.on_dump(*payload.split('#'))
            elif isinstance(topic, (mqtt.spread.topic.Set, mqtt.spread.topic.Renew)):
                self._manager.on_command(topic, mqtt.spread.variable.Variable.of(payload))
            elif isinstance(topic, mqtt.spread.topic.State):
                self._manager.on_state(topic, mqtt.spread.variable.Variable.of(payload))
            elif isinstance(topic, mqtt.project.TopicProject):
                self._manager.on_project(topic=topic, data=payload)
            else:
                logging.debug('[{}] => {}'.format(msg.topic, payload))
        except ClassifierError as ex:
            logging.error(ex)
        except InitError as ex:
            logging.warning(ex)
        except BaseException as ex:
            logging.exception(ex)

    def on_disconnect(self, client, userdata, rc):
        super(DaliManagerLauncher, self).on_disconnect(client, userdata, rc)
        self.on_exit(None, None)


def run():
    DaliManagerLauncher()


if __name__ == '__main__':
    run()
