import spread_core.protocols.dali.device.general as device
import spread_core.protocols.dali.device.light_sensor_ext as device_light
import spread_core.protocols.dali.device.presence_sensor_ext as device_presence
import spread_core.protocols.dali.gear.general as gear
import spread_core.protocols.dali.gear.led as led
import spread_lom as lom
import spread_mercury.commands as mercury

_DEF_GROUPS = [{"index": 0, "value": False}, {"index": 15, "value": False}, {"index": 1, "value": False}, {"index": 2, "value": False}, {"index": 4, "value": False}, {"index": 5, "value": False}, {"index": 6, "value": False}, {"index": 7, "value": False}, {"index": 8, "value": False}, {"index": 9, "value": False}, {"index": 10, "value": False}, {"index": 11, "value": False}, {"index": 12, "value": False}, {"index": 13, "value": False}, {"index": 14, "value": False}, {"index": 3, "value": False}]
_DEF_SCENES = [{"index": 0, "value": 255}, {"index": 1, "value": 255}, {"index": 2, "value": 255}, {"index": 3, "value": 255}, {"index": 4, "value": 255}, {"index": 5, "value": 255}, {"index": 6, "value": 255}, {"index": 7, "value": 255}, {"index": 8, "value": 255}, {"index": 9, "value": 255}, {"index": 10, "value": 255}, {"index": 11, "value": 255}, {"index": 12, "value": 255}, {"index": 13, "value": 255}, {"index": 14, "value": 255}, {"index": 15, "value": 255}]

LOGARITHMIC_CURVE = 'Logarithmic'
LINEAR_CURVE = 'Linear'

classifier = dict(
    Lighting=dict(
        Lighting=dict(On=dict(id=1010001),
                      IsMatchScene1=dict(id=1010003),
                      IsMatchScene2=dict(id=1010004),
                      PowerLevel=dict(id=1010005),
                      IsLightSensorsOn=dict(id=1010006),
                      IsPresenceSensorsOn=dict(id=1010008),
                      BrightnessLevel=dict(id=1010009)),

        SwitchingLight=dict(On=dict(id=1010101),
                            PowerLevel=dict(id=1010102)),

        DimmingLight=dict(On=dict(id=1010201),
                          BrightnessLevel=dict(id=1010202),
                          PowerLevel=dict(id=1010203)),

        RgbLight=dict(On=dict(id=1010301),
                      RgbBrightnessLevel=dict(id=1010302)),

        DynamicLight=dict(On=dict(id=1010401),
                          ScenarioNumber=dict(id=1010402)),

        LightSensor=dict(On=dict(id=1010501)),

        PresenceSensor=dict(On=dict(id=1010601),
                            HoldTime=dict(id=1010602)),

        LightingArea=dict(
            On=dict(id=1010701, state=bool),
            Discovery=dict(id=1010702, state=bool),
            TuningType=dict(id=1010721, variants=['Combo', 'Presence', 'Luminosity', 'Idle'], state=str, def_value='Combo'),
            OccupancyLevel=dict(id=1010722, state=int),
            VacancyLevel=dict(id=1010723, state=int),
            TargetLuminosity=dict(id=1010724, state=int),
            Hysteresis=dict(id=1010725, state=int),
            TuningSpeed=dict(id=1010726, state=int),
            OccupancyAction=dict(id=1010727, variants=['MaxLevel', 'LastLevel', 'Level', 'Scene'], state=str, def_value='LastLevel'),
            OccupancyScene=dict(id=1010728, state=int),
            VacancyAction=dict(id=1010729, variants=['Off', 'MinLevel', 'Level', 'Scene'], state=str, def_value='MinLevel'),
            VacancyScene=dict(id=1010730, state=int),
            Presence=dict(id=1010771, state=bool),
            Luminosity=dict(id=1010772, state=int),
            Pause=dict(id=1010773, state=int),
            CurrentProfile=dict(id=1010774, state=int),
            Profiles=dict(id=1010775, state=dict),
            HoldTime=dict(id=1010777, state=int),
            VacancySceneLoad=dict(id=1010778, set=dict(value=None)),
            VacancySceneSave=dict(id=1010779, set=dict(value=None)),
            OccupancySceneLoad=dict(id=1010780, set=dict(value=None)),
            OccupancySceneSave=dict(id=1010781, set=dict(value=None)),
            Buttons=dict(id=1010782, state=dict),
        ),
    ),

    # Hardware::Spread::Dali
    Dali=dict(
        Bus=dict(id=32090001, get=dict(func='GetScan'), run=dict(func='scan')),
        Status=dict(id=32090002, state=bool),
        DaliDimmer=dict(
            BrightnessLevel=dict(id=32090102, state=int),
            Address=dict(id=32090110, set=dict(func='SetShortAddress')), # null - удаление адреса)
            Types=dict(id=32090112, state=list),
            Discovery=dict(id=32090113, state=bool),
            CurrentLevelRaw=dict(id=32090114, state=int),
            CurrentLevel=dict(id=32090115),
            PhysicalMinLevelRaw=dict(id=32090116, state=int),
            PhysicalMinLevel=dict(id=32090117),
            MinLevelRaw=dict(id=32090118, state=int, def_value=1),
            MinLevel=dict(id=32090119),
            MaxLevelRaw=dict(id=32090120, state=int),
            MaxLevel=dict(id=32090121),
            PowerOnLevelRaw=dict(id=32090122, state=int),
            PowerOnLevel=dict(id=32090123),
            SystemFailureLevelRaw=dict(id=32090124, state=int, def_value=255),
            SystemFailureLevel=dict(id=32090125),
            SceneLevelsRaw=dict(id=32090126, state=list, def_value=_DEF_SCENES),
            SceneLevels=dict(id=32090127),
            Groups=dict(id=32090128, state=list, def_value=_DEF_GROUPS),
            FadeTime=dict(id=32090129, state=str, variants=["ft0", "ft7", "ft10", "ft14", "ft20", "ft28", "ft40", "ft57", "ft80", "ft113", "ft160", "ft226", "ft320", "ft453", "ft640", "ft905"], def_value='ft0'),
            FadeRate=dict(id=32090130, state=str, variants=["fr3580", "fr2530", "fr1790", "fr1270", "fr894", "fr633", "fr447", "fr316", "fr224", "fr158", "fr112", "fr79", "fr56", "fr40", "fr28"], def_value='fr3580'),
            DimmingCurve=dict(id=32090131, state=str, variants=[LOGARITHMIC_CURVE, LINEAR_CURVE], def_value=LOGARITHMIC_CURVE),
            GroupLevel=dict(id=32090132, state=int),
            Gtin=dict(id=32090141, state=str),
            Serial=dict(id=32090142, state=str),
            GtinOem=dict(id=32090143, state=str),
            SerialOem=dict(id=32090144, state=str),
            FirmwareVersion=dict(id=32090145, state=str),
            HardwareVersion=dict(id=32090146, state=str),
            Binding=dict(id=32090181, def_value='Device', state=str),
            BindingDevice=dict(id=32090182, state=int),
            BindingGroup=dict(id=32090183, state=int),
            Tuning=dict(id=32090191, state=float),
        ),
        DaliTunableWhite=dict(
            BrightnessLevel=dict(id=32090502, state=int),
            Address=dict(id=32090510, set=dict(func='SetShortAddress')), # null - удаление адреса)
            Types=dict(id=32090512, state=list),
            Discovery=dict(id=32090513, state=bool),
            CurrentLevelRaw=dict(id=32090514, state=int),
            CurrentLevel=dict(id=32090515),
            PhysicalMinLevelRaw=dict(id=32090516, state=int),
            PhysicalMinLevel=dict(id=32090517),
            MinLevelRaw=dict(id=32090518, state=int, def_value=1),
            MinLevel=dict(id=32090519),
            MaxLevelRaw=dict(id=32090520, state=int),
            MaxLevel=dict(id=32090521),
            PowerOnLevelRaw=dict(id=32090522, state=int),
            PowerOnLevel=dict(id=32090523),
            SystemFailureLevelRaw=dict(id=32090524, state=int, def_value=255),
            SystemFailureLevel=dict(id=32090525),
            SceneLevelsRaw=dict(id=32090526, state=list, def_value=_DEF_SCENES),
            SceneLevels=dict(id=32090527),
            Groups=dict(id=32090528, state=list, def_value=_DEF_GROUPS),
            FadeTime=dict(id=32090529, state=str, variants=["ft0", "ft7", "ft10", "ft14", "ft20", "ft28", "ft40", "ft57", "ft80", "ft113", "ft160", "ft226", "ft320", "ft453", "ft640", "ft905"], def_value='ft0'),
            FadeRate=dict(id=32090530, state=str, variants=["fr3580", "fr2530", "fr1790", "fr1270", "fr894", "fr633", "fr447", "fr316", "fr224", "fr158", "fr112", "fr79", "fr56", "fr40", "fr28"], def_value='fr3580'),
            DimmingCurve=dict(id=32090531, state=str, variants=[LOGARITHMIC_CURVE, LINEAR_CURVE], def_value=LOGARITHMIC_CURVE),
            GroupLevel=dict(id=32090532, state=int),
            Gtin=dict(id=32090541, state=str),
            Serial=dict(id=32090542, state=str),
            GtinOem=dict(id=32090543, state=str),
            SerialOem=dict(id=32090544, state=str),
            FirmwareVersion=dict(id=32090545, state=str),
            HardwareVersion=dict(id=32090546, state=str),
            Binding=dict(id=32090581, def_value='Device', state=str),
            BindingDevice=dict(id=32090582, state=int),
            BindingGroup=dict(id=32090583, state=int),
            Tuning=dict(id=32090591, state=float),
            Temperature=dict(id=32090596, state=int),
            Warmest=dict(id=32090597, state=int),
            Coolest=dict(id=32090598, state=int),
        ),
        DaliRelay=dict(
            BrightnessLevel=dict(id=32090202, state=int),
            Address=dict(id=32090210, set=dict(func='SetShortAddress')), # null - удаление адреса)
            Types=dict(id=32090212, state=list, value=int),
            Discovery=dict(id=32090213, state=bool),
            CurrentLevelRaw=dict(id=32090214, state=int),
            CurrentLevel=dict(id=32090215),
            PhysicalMinLevelRaw=dict(id=32090216, state=int),
            PhysicalMinLevel=dict(id=32090217),
            MinLevelRaw=dict(id=32090218, state=int, def_value=1),
            MinLevel=dict(id=32090219),
            MaxLevelRaw=dict(id=32090220, state=int),
            MaxLevel=dict(id=32090221),
            PowerOnLevelRaw=dict(id=32090222, state=int),
            PowerOnLevel=dict(id=32090223),
            SystemFailureLevelRaw=dict(id=32090224, state=int),
            SystemFailureLevel=dict(id=32090225),
            SceneLevelsRaw=dict(id=32090226, state=list, def_value=_DEF_SCENES),
            SceneLevels=dict(id=32090227),
            Groups=dict(id=32090228, state=list, def_value=_DEF_GROUPS),
            FadeTime=dict(id=32090229, state=str, variants=["ft0", "ft7", "ft10", "ft14", "ft20", "ft28", "ft40", "ft57", "ft80", "ft113", "ft160", "ft226", "ft320", "ft453", "ft640", "ft905"], def_value='ft0'),
            FadeRate=dict(id=32090230, state=str, variants=["fr3580", "fr2530", "fr1790", "fr1270", "fr894", "fr633", "fr447", "fr316", "fr224", "fr158", "fr112", "fr79", "fr56", "fr40", "fr28"], def_value='fr3580'),
            DimmingCurve=dict(id=32090231, state=str, variants=[LOGARITHMIC_CURVE, LINEAR_CURVE], def_value=LOGARITHMIC_CURVE),
            GroupLevel=dict(id=32090232, state=int),
            Gtin=dict(id=32090241, state=str),
            Serial=dict(id=32090242, state=str),
            GtinOem=dict(id=32090243, state=str),
            SerialOem=dict(id=32090244, state=str),
            FirmwareVersion=dict(id=32090245, state=str),
            HardwareVersion=dict(id=32090246, state=str),
            Binding=dict(id=32090281, def_value='Device', state=str),
            BindingDevice=dict(id=32090282, state=int),
            BindingGroup=dict(id=32090283, state=int),
        ),
        DaliLightSensor=dict(
            On=dict(id=32090601, state=bool),
            Discovery=dict(id=32090602, state=bool),
            Binding=dict(id=32090611, def_value='Device', state=str),
            BindingDevice=dict(id=32090612, state=int),
            BindingGroup=dict(id=32090613, state=int),
            Address=dict(id=32090621, set=dict(func='SetShortAddress')), # null - удаление адреса
            OperationMode=dict(id=32090622, state=int),
            Groups=dict(id=32090623, state=list),
            Group0=dict(id=32090624, state=int),
            Group1=dict(id=32090625, state=int),
            Group2=dict(id=32090626, state=int),
            EventScheme=dict(id=32090627, state=str, variants=["esIndexAndType", "esAddressAndType", "esAddressAndIndex", "esLowestGroupAndType", "esPrimaryGroupAndType"], def_value='esIndexAndType'),
            EventPriority=dict(id=32090628, state=int),
            EventFilter=dict(id=32090629, state=list, mask=["illuminanceLevelEvents"]),
            DeadTime=dict(id=32090630, state=int),
            ReportTime=dict(id=32090631, state=int),
            Hysteresis=dict(id=32090632, state=int),
            HysteresisMin=dict(id=32090633, state=int),
            Gtin=dict(id=32090641, state=str),
            Serial=dict(id=32090642, state=str),
            GtinOem=dict(id=32090643, state=str),
            SerialOem=dict(id=32090644, state=str),
            FirmwareVersion=dict(id=32090645, state=str),
            HardwareVersion=dict(id=32090646, state=str),
            InstancesNumber=dict(id=32090647, state=int),
            InstanceIndex=dict(id=32090648, state=int),
            InstanceType=dict(id=32090649, state=int),
            FeatureTypes=dict(id=32090650, state=list),
            Resolution=dict(id=32090651, state=int),
            Event=dict(id=32090661, state=int), # (Last Event Data, 10bit)
            CurrentLuminosity=dict(id=32090662, state=int)
        ),
        DaliPresenceSensor=dict(
            On=dict(id=32090701, state=bool),
            Discovery=dict(id=32090702, state=bool),
            Binding=dict(id=32090711, def_value='Device', state=str),
            BindingDevice=dict(id=32090712, state=int),
            BindingGroup=dict(id=32090713, state=int),
            Address=dict(id=32090721), # null - удаление адреса
            OperationMode=dict(id=32090722, state=int),
            Groups=dict(id=32090723, state=list),
            Group0=dict(id=32090724, state=int),
            Group1=dict(id=32090725, state=int),
            Group2=dict(id=32090726, state=int),
            EventScheme=dict(id=32090727, state=str, variants=["esIndexAndType", "esAddressAndType", "esAddressAndIndex", "esLowestGroupAndType", "esPrimaryGroupAndType"], def_value='esIndexAndType'),
            EventPriority=dict(id=32090728, state=int),
            EventFilter=dict(id=32090729, state=list, value=str, mask=["occupiedEvents", "vacantEvents", "repeatEvents", "movementEvents", "noMovementEvents"]),
            DeadTime=dict(id=32090730, state=int),
            ReportTime=dict(id=32090731, state=int),
            HoldTime=dict(id=32090732, state=int),
            Gtin=dict(id=32090741, state=str),
            Serial=dict(id=32090742, state=str),
            GtinOem=dict(id=32090743, state=str),
            SerialOem=dict(id=32090744, state=str),
            FirmwareVersion=dict(id=32090745, state=str),
            HardwareVersion=dict(id=32090746, state=str),
            InstancesNumber=dict(id=32090747, state=int),
            InstanceIndex=dict(id=32090748, state=int),
            InstanceType=dict(id=32090749, state=int),
            FeatureTypes=dict(id=32090750, state=list),
            Resolution=dict(id=32090751, state=int),
            Event=dict(id=32090761, state=int), #  (Last Event Data, 10bit)
            CurrentPresence=dict(id=32090762, state=int),
            EngineryHoldTime=dict(id=32090763, state=int),
        ),
        DaliPushButton=dict(
            On=dict(id=32090801, state=bool),
            Binding=dict(id=32090811, state=str),
            BindingDevice=dict(id=32090812, state=int),
            BindingGroup=dict(id=32090813, state=int),
            Address=dict(id=32090821), # null - удаление адреса
            OperationMode=dict(id=32090822, state=int),
            Groups=dict(id=32090823, state=list),
            Group0=dict(id=32090824, state=int),
            Group1=dict(id=32090825, state=int),
            Group2=dict(id=32090826, state=int),
            EventScheme=dict(id=32090827, state=str, variants=["esIndexAndType", "esAddressAndType", "esAddressAndIndex", "esLowestGroupAndType", "esPrimaryGroupAndType"], def_value='esIndexAndType'),
            EventPriority=dict(id=32090828, state=int),
            EventFilter=dict(id=32090829, state=list, value=str, mask=["buttonReleasedEvents", "buttonPressedEvents", "shortPressEvents", "doublePressEvents", "longPressStartEvents", "longPressRepeatEvents", "longPressStopEvents", "buttonStuckFreeEvents"]),
            ShortTime=dict(id=32090830, state=int),
            ShortTimeMin=dict(id=32090831, state=int),
            DoubleTime=dict(id=32090832, state=int),
            DoubleTimeMin=dict(id=32090833, state=int),
            RepeatTime=dict(id=32090834, state=int),
            StuckTime=dict(id=32090835, state=int),
            Gtin=dict(id=32090841, state=str),
            Serial=dict(id=32090842, state=str),
            GtinOem=dict(id=32090843, state=str),
            SerialOem=dict(id=32090844, state=str),
            FirmwareVersion=dict(id=32090845, state=str),
            HardwareVersion=dict(id=32090846, state=str),
            InstancesNumber=dict(id=32090847, state=int),
            InstanceIndex=dict(id=32090848, state=int),
            InstanceType=dict(id=32090849, state=int),
            FeatureTypes=dict(id=32090850, state=list),
            Resolution=dict(id=32090851, state=int),
            LastEvent=dict(id=32090862, state=int), #  (Last Event Data, 10bit)
        ),
    ),
    Mercury=dict(
        Status=dict(id=41010002, state=bool),
        MercuryElectricMeter=dict(
            Validity=dict(id=41010121, ),
            Info=dict(id=41010101),
            PowerActive=dict(id=41010102, ),
            PowerReactive=dict(id=41010103, ),
            PowerTotal=dict(id=41010104, ),
            Voltage=dict(id=41010105, ),
            Amperage=dict(id=41010106, ),
            Angle=dict(id=41010107, ),
            Frequency=dict(id=41010108, ),
            PowerRate=dict(id=41010109, ),
            StoredEnergy=dict(id=41010110, ),
            Temperature=dict(id=41010111, ),
            SerialDate=dict(id=41010112, ),
            CurrentDateTime=dict(id=41010113, ),
            OpenCloseTime=dict(id=41010114, ),
            Version=dict(id=41010115, ),
            RateVoltage=dict(id=41010116, ),
            RateAmperage=dict(id=41010117, ),
            PulseMode=dict(id=41010118, ),
            Status=dict(id=41010119, ),
            LoadOn=dict(id=41010120, ),
        )
    ),
    Lom=dict(
        Status=dict(id=41020001, state=bool),
        Profiles=dict(id=41020002, set=dict(func='SetProfiles'), state=list),
        AirBitStreetLamp={
            lom.const.BRIGHTNESS_LEVEL:     dict(id=41020011, set=dict(func='SetBrightnessLevel'), state=int),
            lom.const.CONFIG:               dict(set=dict(cmd=lom.commands.SetConfig), get=dict(cmd=lom.commands.GetConfig)),
            lom.const.CURRENT_PROFILE:      dict(set=dict(func='SetCurrentProfile')),
            'GroupLevel':                    dict(id=41020011, set=dict(func='SetBrightnessLevel'), state=int),
            # lom.const.OPER_TIME: dict(id=41020102),
            # lom.const.CURRENT_PROFILE_ID: dict(id=41020106),
            # lom.const.TEMP: dict(id=41020107),
            # lom.const.TEMP_MIN: dict(id=41020108),
            # lom.const.TEMP_MAX: dict(id=41020109),
            # lom.const.ILLUMINATION: dict(id=41020110),
            # lom.const.TILT: dict(id=41020111),
            # lom.const.FLAGS: dict(id=41020112),
            # lom.const.DEVICE_SERIAL:                dict(id=41020113, c_id=1, size=4, get=lom.commands.GetConf),
            # lom.const.DEVICE_MODEL_ID:              dict(id=41020114, c_id=2, size=1, get=lom.commands.GetConf),
            # lom.const.FIRMWARE_VERSION:             dict(id=41020115, c_id=3, size=1, get=lom.commands.GetConf),
            # lom.const.ACTIVATION_STATUS:            dict(id=41020116, c_id=4, size=1, get=lom.commands.GetConf),
            # lom.const.DEVICE_USER_PASS:             dict(id=41020117, c_id=5, size=4, get=lom.commands.GetConf, state=str),
            # lom.const.LORAWAN_MC_ADDRESS_GROUP1:    dict(id=41020118, c_id=6, size=4, get=lom.commands.GetConf),
            # lom.const.LORAWAN_DEV_EUI:              dict(id=41020119, c_id=7, size=8, get=lom.commands.GetConf),
            # lom.const.LORAWAN_NETWORK_ID:           dict(id=41020120, c_id=257, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_REGION:               dict(id=41020121, c_id=258, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, variants=['AS923', 'AU915', 'CN470', 'CN779', 'EU433', 'EU868', 'KR920', 'IN865', 'US915', 'RU864']),
            # lom.const.LORAWAN_CLASS:                dict(id=41020122, c_id=259, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, variants=['CLASS_A', 'CLASS_B', 'CLASS_C']),
            # lom.const.LORAWAN_NB_TRIALS:            dict(id=41020123, c_id=260, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_TX_DATARATE:          dict(id=41020124, c_id=261, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, format='DT{}'),
            # lom.const.LORAWAN_IS_PUBLIC_NETWORK:    dict(id=41020125, c_id=262, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            # lom.const.LORAWAN_ADR_ENABLED:          dict(id=41020126, c_id=263, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            # lom.const.LORAWAN_MULTICAST_GROUP1_EN:  dict(id=41020127, c_id=264, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            # lom.const.LORAWAN_MULTICAST_GROUP2_EN:  dict(id=41020128, c_id=281, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            # lom.const.LORAWAN_MULTICAST_GROUP3_EN:  dict(id=41020129, c_id=282, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            # lom.const.LORAWAN_MULTICAST_GROUP4_EN:  dict(id=41020130, c_id=283, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            # lom.const.LORAWAN_REJOIN_INTERVAL_SEC:  dict(id=41020131, c_id=265, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_TIMESYNC_INTERVAL_SEC:dict(id=41020132, c_id=266, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_SEND_INTERVAL_SEC:    dict(id=41020133, c_id=267, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_NWKCHECK_INTERVAL_SEC:dict(id=41020134, c_id=268, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_NWKCHECK_ATTEMPTS:    dict(id=41020135, c_id=269, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LORAWAN_CONFIRMATION_ENABLED: dict(id=41020136, c_id=270, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, state=bool),
            #
            # lom.const.LATITUDE:                     dict(id=41020137, c_id=271, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.LONGITUDE:                    dict(id=41020138, c_id=272, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.ALTITUDE:                     dict(id=41020139, c_id=273, size=2, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.ANGLE_THRESHOLD:              dict(id=41020140, c_id=274, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.ACCEL_SENSITIVITY:            dict(id=41020141, c_id=275, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf, variants=['Off', 'Low', 'Middle', 'High']),
            # lom.const.DALI_SCAN_INTERVAL:           dict(id=41020142, c_id=276, size=2, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.ANSWER_RAND_INTERVAL:         dict(id=41020143, c_id=277, size=4, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # lom.const.DALI_ACTIVE_GLOBAL_PROFILE:   dict(id=41020144, c_id=278, size=1, get=lom.commands.GetConf, set=lom.commands.SetConf),
            # 'TempDimming':                          dict(id=41020144, set=lom.commands.SetDimmingLevel)
        }
    )
)
