import re

from . import Topic


class ProjectHash(Topic):
    protocol = 'Project'
    HASH = 'Hash'

    def __init__(self, project_id: int):
        self.project_id = project_id

    def __str__(self): return '/'.join((self.protocol, str(self.project_id), self.HASH))


class TopicProject(Topic):
    ENGINERIES = 'engineries'
    PROVIDERS = 'providers'
    MANAGERS = 'managers'
    SUBGINERIES = 'subgineries'
    HEADER = 'header'
    SERVERS = 'servers'
    LOCATIONS = 'locations'
    MODELS = 'models'
    CTP = 'Ctp'

    protocol = 'Project'
    topic_type = 'File'

    def __init__(self, p_id, file_name):
        self.p_id = p_id
        self.file_name = file_name

    def __str__(self):
        if self.file_name == TopicProject.CTP:
            return f'{self.protocol}/{self.p_id}/{self.file_name}'
        return f'{self.protocol}/{self.p_id}/{self.topic_type}/{self.file_name}'

    @classmethod
    def engineries(cls, p_id): return cls(p_id, f'{TopicProject.ENGINERIES}.json')

    @classmethod
    def subgineries(cls, p_id): return cls(p_id, f'{TopicProject.SUBGINERIES}.json')

    @classmethod
    def providers(cls, p_id): return cls(p_id, f'{TopicProject.PROVIDERS}.json')

    @classmethod
    def managers(cls, p_id): return cls(p_id, f'{TopicProject.MANAGERS}.json')

    @classmethod
    def servers(cls, p_id): return cls(p_id, f'{TopicProject.SERVERS}.json')

    @classmethod
    def header(cls, p_id): return cls(p_id, f'{TopicProject.HEADER}.json')

    @classmethod
    def locations(cls, p_id): return cls(p_id, f'{TopicProject.LOCATIONS}.json')

    @classmethod
    def ctp(cls, p_id): return cls(p_id, TopicProject.CTP)


class Local(Topic):
    protocol = 'Local'

    def __init__(self, project_id):
        self.project_id = project_id

    def __str__(self): raise NotImplementedError()

    @classmethod
    def of(cls, topic: str):
        if re.search(r'%s/\d+/%s' % (TopicProject.protocol, cls.protocol), topic):
            return LAButtonPresets(*re.search(r'%s/(\d+)/%s/.+/(\d+)$' % (TopicProject.protocol, cls.protocol), topic).groups())

        raise


class LAButtonPresets(Local):
    type = 'Equipment/Lighting/LightingArea/ButtonPresets'

    @staticmethod
    def broadcast(project_id): return '/'.join(('Project', str(project_id), LAButtonPresets.protocol, LAButtonPresets.type, '#'))

    def __init__(self, project_id: int, entity_id: int):
        super(LAButtonPresets, self).__init__(project_id)
        self.entity_id = int(entity_id) if isinstance(entity_id, str) and entity_id.isdigit() else entity_id

    def __str__(self):
        return '/'.join(('Project', str(self.project_id), self.protocol, self.type, str(self.entity_id)))
