import json
from datetime import datetime


class Variable:
    def __init__(self, value, timestamp: datetime = None, invalid=False, key=None, session=None, params=None,
                 inconsistent=False):
        self._value = value
        self._invalid = invalid or value is None
        self._inconsistent = inconsistent
        self._key = key
        self._session_id = session
        self._params = params if params else {}

        if isinstance(timestamp, str):
            self._timestamp = datetime.fromisoformat(timestamp)
        elif timestamp is None:
            self._timestamp = datetime.now()
        else:
            self._timestamp = timestamp

    value = property(fget=lambda self: self._value, doc='value')
    timestamp = property(fget=lambda self: self._timestamp, doc='timestamp')
    invalid = property(fget=lambda self: self._invalid, doc='invalid')
    inconsistent = property(fget=lambda self: self._inconsistent, doc='inconsistent')

    def clear_signature(self):
        self._key = None
        self._session_id = None

    @property
    def key(self): return self._key

    @key.setter
    def key(self, key): self._key = key

    @property
    def session_id(self): return self._session_id

    @property
    def params(self): return self._params

    @classmethod
    def of(cls, data: (dict, bytes, str)):
        if isinstance(data, (bytes, bytearray)):
            data = data.decode()

        if isinstance(data, str):
            data = json.loads(data)

        return cls(value=data.pop('value', None),
                   timestamp=data.pop('timestamp', None),
                   invalid=data.pop('invalid', False),
                   session=data.pop('session', None),
                   key=data.pop('key', None),
                   params=data.pop('params', {}))

    def __str__(self):
        return ('(Inv) ' if self.invalid else '') + \
               (f'{self._value}'.ljust(11, " ") if self.value is not None else '') + \
               (' ' + '; '.join([f'{key}={value}' for key, value in self.params.items()]) if self.params else '')

    def __iter__(self):
        data = dict()

        # data['timestamp'] = self._timestamp.astimezone().isoformat()

        if self._invalid: data['invalid'] = True
        if self._inconsistent: data['inconsistent'] = True
        if self.value is not None: data['value'] = self._value
        if self.key: data['key'] = self.key
        if self.session_id: data['session'] = self.session_id
        if self.params: data['params'] = self.params

        return data

    def pack(self):
        return json.dumps(self.__iter__())
