import json
import logging
import os
import shutil
import sys
import zipfile
import zlib

import spread_core.mqtt as mqtt
import spread_core.tools.settings as settings
from spread_core.tools.service_launcher import Launcher


class ProjectAdapterLauncher(Launcher):
    _dumped = False
    _def_start_delay = 0

    def __init__(self):
        self._manager = self
        self.ctp_topic = None
        self.zip_hash = None
        self.zip_data = None
        super(ProjectAdapterLauncher, self).__init__()

    def connect(self):
        zip_path = settings.config.get(settings.CTP_PATH, None)
        if zip_path is None:
            raise BaseException(f'"{settings.CTP_PATH}" is not set!')

        try:
            with open(zip_path.replace(".ctp", ".hash"), 'r') as hash_file:
                last_hash = int(hash_file.read().strip())
        except:
            last_hash = -1

        with open(zip_path, 'rb') as zip_file:
            self.zip_data = zip_file.read()

        self.zip_hash = zlib.crc32(self.zip_data)

        logging.info('run migrate spread_dashboard')
        os.system('sudo spread_utils_dashboard migrate spread_dashboard')
        logging.info('migrate OK')

        if self.zip_hash != last_hash:
            db = settings.config.get(settings.MOSQUITTO_PATH, '/var/lib/mosquitto/')
            logging.info('mosquitto clean...')
            os.system('sudo service mosquitto stop')
            if os.path.isdir(db):
                shutil.rmtree(db, ignore_errors=True)
            elif os.path.isfile(db):
                os.remove(db)
            os.system('sudo service mosquitto start')
            logging.info('mosquitto cleaned')

            logging.info('run filling dashboard')
            os.system('sudo spread_utils_dashboard fill --all')
            logging.info('filling OK')
            super(ProjectAdapterLauncher, self).connect()
        else:
            logging.info('run filling dashboard')
            os.system('sudo spread_utils_dashboard fill --tasks --calendar')
            logging.info('filling OK')
            logging.info('Projects HASH is not changed')

    def start(self):
        zip_path = settings.config.get(settings.CTP_PATH, None)
        hash_path = zip_path.replace(".ctp", ".hash")

        input_zip = zipfile.ZipFile(zip_path, 'r')

        project_id = json.loads(input_zip.read('header.json'))['header']['project']['id']

        for file in input_zip.namelist():
            if file != mqtt.project.TopicProject.MODELS + '.json':
                self.publish(mqtt.project.TopicProject(project_id, file), json.dumps(json.loads(input_zip.read(file))))

        with open(hash_path, 'w') as hash_file:
            hash_file.write(str(self.zip_hash))

        self.ctp_topic = mqtt.project.TopicProject.ctp(project_id)
        self.subscribe(self.ctp_topic)
        self.publish(self.ctp_topic, self.zip_data)

    def publish(self, topic, data, retain=True):
        try:
            self.mqttc.publish(topic=str(topic), payload=data, retain=retain)
        except BaseException as ex:
            logging.exception(ex)
        else:
            logging.info('Published', topic)

    def on_message(self, mosq, obj, msg):
        if msg.topic == str(self.ctp_topic):
            size = round(len(msg.payload)/1024, 2)
            logging.info(f'CTP packet of {size} kB received. Exit')
            self.mqttc.loop_stop(True)
            self.mqttc.disconnect()
            sys.exit(0)


def run():
    ProjectAdapterLauncher()
    logging.info('Exit ' + ProjectAdapterLauncher.__name__)


if __name__ == '__main__':
    run()
