import logging

import paho.mqtt.client


class MqttClient(paho.mqtt.client.Client):
    CONNECT_RESULTS = ['Connection successful',
                       'Connection refused - incorrect protocol version',
                       'Connection refused - invalid client identifier',
                       'Connection refused - server unavailable',
                       'Connection refused - bad username or password',
                       'Connection refused - not authorised']

    def __init__(self, owner, login, password, on_connect, on_message, on_subscribe=None, on_publish=None,
                 on_close=None, on_log=None, on_unsubscribe=None, on_disconnect=None):

        super().__init__(userdata=owner.__class__.__name__, clean_session=True)
        self._connect_handler = on_connect
        self._disconnect_handler = on_disconnect
        self.username_pw_set(login, password)
        self.on_connect = self.__on_connect
        self.on_disconnect = self.__on_disconnect
        self.on_message = on_message
        self.on_subscribe = on_subscribe
        self.on_publish = on_publish
        self.on_socket_close = on_close
        self.on_log = on_log
        self.on_unsubscribe = on_unsubscribe
        self._rc = None

    @property
    def connected(self):
        return self._rc == 0

    def __on_disconnect(self, client, userdata, rc):
        self._rc = rc
        logging.info(self.CONNECT_RESULTS[rc])
        if self._disconnect_handler:
            self._disconnect_handler(client, userdata, rc)

    def __on_connect(self, mosq, obj, flags, rc):
        self._rc = rc
        logging.info(self.CONNECT_RESULTS[rc])
        if rc == 0:
            self._connect_handler()
