import datetime

from django import forms
from django.utils.datetime_safe import date

from . import models
from ..project.models import Location


class ModelForm(forms.ModelForm):

    def __init__(self, *args, **kwargs):
        super(ModelForm, self).__init__(*args, **kwargs)
        if 'instance' in kwargs:
            self.id = kwargs['instance'].id

    def save(self, commit=True):
        super(ModelForm, self).save(commit)
        if not hasattr(self, 'id'):
            self.id = self.instance.id


class CycleForm(ModelForm):
    @property
    def triggers(self): return [IncTriggerForm(instance=trigger) for trigger in self.instance.triggers]

    class Meta:
        model = models.Cycle
        fields = '__all__'
        widgets = {
            'name': forms.TextInput(attrs={'class': 'input-item'}),
            'startLevel': forms.NumberInput(attrs={'class': 'input-item', 'max': 100}),
            'duration': forms.NumberInput(attrs={'class': 'input-item', 'max': 60*12}),
            'period': forms.NumberInput(attrs={'class': 'input-item', 'max': 30*6}),
        }


class LocationForm(ModelForm):
    class Meta:
        model = Location
        fields = ['id', 'incubated', 'name']


class IncubatorForm(ModelForm):
    def __init__(self, *args, **kwargs):
        super(IncubatorForm, self).__init__(*args, **kwargs)
        if self.instance.cycle:
            self.fields['startTime'].widget.choices = self.days(self.instance.cycle.period)

    @staticmethod
    def days(period): return (('', ''), *(
        (date.today() - datetime.timedelta(days=i), '%s день' % (i+1))
        for i in range(0, period)
    ))

    class Meta:
        model = models.Incubator
        fields = ['cycle', 'startTime', 'active']
        widgets = {
            'cycle': forms.Select(attrs={'class': 'input-item'}),
            'startTime': forms.Select(attrs={'class': 'input-item'}),
        }


class IncTriggerForm(ModelForm):

    def __init__(self, *args, **kwargs):
        super(IncTriggerForm, self).__init__(*args, **kwargs)
        self.fields['level'].widget.attrs['id'] = 'id_level_%s'%self.instance.id
        self.fields['time'].widget.attrs['id'] = 'id_time_%s'%self.instance.id

    class Meta:
        model = models.IncTrigger
        fields = '__all__'
        widgets = {
            'time': forms.TextInput(attrs={'class': 'input-item', 'type': 'time'}),
            'level': forms.NumberInput(attrs={'class': 'input-item', 'max': 100})
        }
