import json

from django.http import HttpResponseNotFound, HttpResponse
from django.shortcuts import redirect, render

from spread_dashboard.incubator import models, forms


def index(request):
    return render(request, 'incubator/cycles.html', dict(items=models.Cycle.objects.all()))


def create(request):
    models.Cycle.objects.create()
    return redirect(request.path[:request.path.index('create/')])


def edit(request, cid):
    try:
        instance = models.Cycle.objects.get(id=cid)
    except models.Cycle.DoesNotExist as ex:
        return HttpResponseNotFound(str(ex))
    else:
        if request.method == 'POST':
            form = forms.CycleForm(request.POST, instance=instance)
            if form.is_valid():
                if form.changed_data:
                    form.save()
                return redirect(request.path)
        else:
            form = forms.CycleForm(instance=instance)

        return render(request, 'incubator/views/cycle.html', dict(
            form=form,
            days={
                trigger.id: [trigger.day, trigger.time.hour*60+trigger.time.minute, trigger.level]
                for trigger in models.IncTrigger.objects.filter(cycle=instance).order_by('day', 'time')
            }
        ))


def remove(request, cid):
    models.Cycle.objects.get(id=cid).delete()
    return redirect(request.path[:request.path.index('remove')])


def copy(request, cid):
    template = models.Cycle.objects.get(id=cid)
    model = models.Cycle.objects.create(**{
        key: value
        for key, value in template.__dict__.items()
        if key in models.Cycle.copied_fields()
    })

    for trigger in template.triggers:
        models.IncTrigger.objects.create(
            cycle=model,
            **{
                key: value
                for key, value in trigger.__dict__.items()
                if key in models.IncTrigger.copied_fields()
            })
    return redirect(request.path[:request.path.index('copy')])


def copy_triggers(request, cid):
    template_day = int(request.GET.get('template'))
    target_day = int(request.GET.get('day'))
    models.IncTrigger.objects.filter(cycle_id=cid, day=target_day).delete()
    templates = models.IncTrigger.objects.filter(cycle_id=cid, day=template_day)
    for template in templates:
        models.IncTrigger.objects.create(**{
            **{
                key: value
                for key, value in template.__dict__.items()
                if key in models.IncTrigger.copied_fields()
            },
            'cycle_id': cid,
            'day': target_day
        })
    return triggers(request, cid)


def triggers(request, cid):
    day = int(request.GET.get('day'))
    return HttpResponse(json.dumps(
        {
            'day': day,
            'count': models.Cycle.objects.get(id=cid).period,
            'triggers': [
                trigger_view(request, forms.IncTriggerForm(instance=trigger)).content.decode()
                for trigger in models.IncTrigger.objects.filter(day=day, cycle_id=cid).order_by('time')
            ]
        }
    ))


def add_trigger(request, cid):
    return trigger_view(request, forms.IncTriggerForm())


def edit_trigger(request, cid):
    form = forms.IncTriggerForm(request.POST)
    if request.method == 'POST':
        try:
            form.instance.id = int(request.POST.get('id'))
        except: pass
        form.instance.cycle_id = cid

        if 'remove' in request.POST:
            models.IncTrigger.objects.get(id=form.instance.id).delete()
        elif form.is_valid():
            if form.changed_data:
                form.save()

    return trigger_view(request, form)


def trigger_view(request, form):
    return render(request, 'incubator/views/trigger.html', dict(trigger=form))
