from django.http.response import HttpResponse
from django.shortcuts import redirect, render

from spread_dashboard.incubator import models, forms


def index(request):
    return render(request, 'incubator/locations.html',
                  dict(
                      items=models.Incubator.objects.all(),
                      locations=(('', 'Выберите помещение'), *models.Location.objects.exclude(
                          id__in=models.Incubator.objects.values_list('location')
                      ).values_list('id', 'name'))))


def create(request):
    if request.method == 'POST':
        models.Incubator.objects.create(location_id=int(request.POST.get('location')))
    return redirect(request.path[:request.path.index('create/')])


def edit(request, iid):
    instance = models.Incubator.objects.get(id=iid)
    if request.method == 'POST':
        form = forms.IncubatorForm(request.POST, instance=instance)
        if form.is_valid():
            if form.changed_data:
                form.save()
        return redirect(request.path)
    else:
        form = forms.IncubatorForm(instance=instance)
    return render(request, 'incubator/views/location.html', dict(form=form))


def days(request, iid, cid):
    form = forms.IncubatorForm()
    form.fields['startTime'].widget.choices = forms.IncubatorForm.days(models.Cycle.objects.get(id=cid).period)
    res = form.as_table()
    res = res[res.index('<select name="startTime"'):]
    res = res[:res.index('</select>')+9]
    return HttpResponse(res)


def remove(request, iid):
    models.Incubator.objects.get(id=iid).delete()
    return redirect(request.path[:request.path.index('remove')])
