import logging
import threading

from spread_core.tools.settings_const import BROKER, LOGIN, PASSWORD, HOST, PORT
from spread_core.tools.mqtt_client import MqttClient
from spread_dashboard.project.bam import settings


class WSVendor(threading.Thread):
    def __init__(self):
        super(WSVendor, self).__init__(name=self.__class__.__name__)

        self._mqttc = MqttClient(self,
                                 settings[BROKER][LOGIN],
                                 settings[BROKER][PASSWORD],
                                 self._on_connect, self._on_message)
        self.listeners = {}
        self.start()

    def run(self) -> None:
        self._mqttc.connect(host=settings[BROKER][HOST],
                            port=settings[BROKER][PORT])
        self._mqttc.loop_forever()

    def _on_connect(self):
        pass

    def _on_message(self, mosq, obj, msg):
        for listener in self.listeners.values():
            listener.handler(msg.topic, msg.payload)

    def set_listener(self, group, handler):
        logging.debug('add group ' + group)
        try:
            self.listeners.setdefault(group, Listener(group, handler))
        except BaseException as ex:
            logging.exception(ex)

    def add_subscription(self, group, *topics):
        logging.debug(f'subscribe {topics}')
        for topic in topics:
            self.listeners[group].topics.setdefault(topic, 0)
            self.listeners[group].topics[topic] += 1
            if self.listeners[group].topics[topic] == 1:
                self._mqttc.subscribe(topic)

    def remove_subscription(self, group, *topics):
        logging.debug(f'unsubscribe {topics}')
        for topic in topics:
            if topic in self.listeners[group].topics:
                self.listeners[group].topics[topic] -= 1
                if self.listeners[group].topics[topic] == 0:
                    self._mqttc.unsubscribe(topic)

    def remove_listener(self,  group):
        logging.debug('del group ' + group)
        if group in self.listeners:
            self.remove_subscription(group, *self.listeners[group].topics)
            self.listeners.pop(group)
        else:
            logging.debug(group, ' listener not set')


class Listener:
    def __init__(self, group, handler):
        self.group = group
        self.handler = handler
        self.topics = {}

    def compare(self, _topic):
        for topic in self.topics:
            if topic == _topic:
                return True
            elif '#' in topic:
                if _topic.index(topic[:topic.index('#')]) != -1:
                    return True

        return False
