from django import forms

from . import configs


class BaseForm(forms.ModelForm):
    @classmethod
    def of(cls, *args, **kwargs):
        # CommonForm(request.POST, instance=CommonForm.Meta.model())
        return cls(*args, instance=cls.Meta.model(**kwargs))


class CommonForm(BaseForm):
    class Meta:
        model = configs.Common
        fields = '__all__'
        widgets = {
            'host': forms.TextInput(attrs={'pattern': r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}'}),
            'password': forms.TextInput(attrs={'type': 'password'}),
            'projectID': forms.NumberInput(attrs={'readonly': True}),
        }


class CanAdapterForm(BaseForm):
    @classmethod
    def of(cls, index, *args):
        return super(CanAdapterForm, cls).of(index=index, *args)

    class Meta:
        model = configs.CanAdapter
        fields = '__all__'
        widgets = {
            'canInterface': forms.TextInput(attrs={'readonly': True}),
            'subtopicCan': forms.TextInput(attrs={'readonly': True}),
            'subtopicDali': forms.TextInput(attrs={'readonly': True}),
            'subtopicModbus': forms.TextInput(attrs={'readonly': True}),
        }


class _ManagerForm(BaseForm):
    @classmethod
    def of(cls, bus, *args):
        return super(_ManagerForm, cls).of(bus=bus, *args)


class DaliManagerForm(_ManagerForm):
    class Meta:
        model = configs.DaliManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class MercuryManagerForm(_ManagerForm):
    class Meta:
        model = configs.MercuryManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
            'hexed': forms.TextInput()
        }


class TcpAdapterForm(BaseForm):
    @classmethod
    def of(cls, bus, *args):
        return super(TcpAdapterForm, cls).of(bus=bus, *args)

    class Meta:
        model = configs.TcpAdapter
        fields = '__all__'
        widgets = {
            'subtopic': forms.TextInput(attrs={'readonly': True}),
            'host': forms.TextInput(attrs={'pattern': r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}'}),
            # 'timeout': forms.NumberInput(min_value=0.1),
            # 'killTimeout': forms.NumberInput(min_value=0.1),
        }


class LomManagerForm(BaseForm):
    @classmethod
    def of(cls, *args):
        return super(LomManagerForm, cls).of(*args)

    class Meta:
        model = configs.LomManager
        fields = '__all__'
        widgets = {
            'managerID': forms.NumberInput(attrs={'readonly': True}),
        }


class FrontierForm(BaseForm):
    class Meta:
        model = configs.Frontier
        fields = '__all__'
        widgets = {
            'serverID': forms.NumberInput(attrs={'readonly': True}),
        }


class SchedulerForm(BaseForm):
    class Meta:
        model = configs.Scheduler
        fields = '__all__'
        widgets = {
            'tasks': forms.TextInput(attrs={'readonly': True}),
            'calendar': forms.TextInput(attrs={'readonly': True}),
        }


class CyclerForm(BaseForm):
    class Meta:
        model = configs.Cycler
        fields = '__all__'
        widgets = {
            'data': forms.TextInput(attrs={'readonly': True}),
        }


class ScripterForm(BaseForm):
    class Meta:
        model = configs.Scripter
        fields = '__all__'
        widgets = {
            'triggers': forms.TextInput(attrs={'readonly': True}),
            'calendar': forms.TextInput(attrs={'readonly': True}),
        }


class ProjectorForm(BaseForm):
    class Meta:
        model = configs.Projector
        fields = '__all__'


class EventsSqliteForm(BaseForm):
    class Meta:
        model = configs.EventsSqlite
        fields = '__all__'


class LightingEquipmentForm(BaseForm):
    class Meta:
        model = configs.LightingEquipment
        fields = '__all__'


class DashboardForm(BaseForm):
    class Meta:
        model = configs.Dashboard
        fields = '__all__'
        widgets = {
            'port': forms.TextInput(attrs={'readonly': True}),
        }
