import datetime
import sys

import django.http as http
from dateutil import relativedelta
from django.shortcuts import render

from spread_dashboard.responses import Success
from spread_dashboard.scheduler import models

_month = [None, 'Январь', 'Февраль', 'Март', 'Апрель', 'Май', 'Июнь', 'Июль', 'Август', 'Сентябрь', 'Октябрь', 'Ноябрь',
          'Декабрь']


def on_api(request, api_name):
    if hasattr(sys.modules[__name__], api_name):
        try:
            return getattr(sys.modules[__name__], api_name)(request)
        except BaseException as ex:
            print(str(ex))
            return http.HttpResponseServerError(str(ex))

    return http.HttpResponseNotAllowed(api_name)


def page(request):
    data = dict(locations=models.SchLocation.objects.all())
    return render(request, 'scheduler/scheduler.html', context=data)


def part(request, name):
    return render(request, f'scheduler/{name}.html')


def month(request, m=None, y=None):
    if m is None or y is None:
        date = datetime.date.today()
        m = date.month
        y = date.year
    else:
        m = int(m)
        y = int(y)
        date = datetime.date(y, m, 1)
    weeks = []

    day = datetime.date(date.year, date.month, 1)
    holidays = models.Holiday.objects.filter(date__month=m, date__year=y)

    while day.month == date.month:
        week = []
        for i in range(0, 7):
            classes = []
            if day.month != date.month:
                break
            if day.day == 1 and i < day.weekday():
                week.append('')
            else:
                if day == datetime.date.today():
                    classes.append('current')
                try:
                    holidays.get(date=str(day))
                except:
                    classes.append('work')
                else:
                    classes.append('weekend')
                week.append((' '.join(classes), day.day))
                day += relativedelta.relativedelta(days=1)

        weeks.append(week)
    context = dict(
        name=f'{_month[m]} {y}г.',
        month=m,
        year=y,
        prev_month=(date - relativedelta.relativedelta(months=1, day=1)).month,
        prev_year=(date - relativedelta.relativedelta(months=1, day=1)).year,
        next_month=(date + relativedelta.relativedelta(months=1, day=1)).month,
        next_year=(date + relativedelta.relativedelta(months=1, day=1)).year,
        weeks=weeks
    )
    return render(request, 'scheduler/month.html', context=context)


def get_trigger_div(request):
    return render(request, 'scheduler/trigger.html')


def get_action_div(request):
    return render(request, 'scheduler/action.html')


def get_triggers(request):
    _id = int(request.GET.get('id'))
    _trigger_type = request.GET.get('trigger')
    return Success([
        dict(
            id=trigger.id,
            time=str(trigger.time),
            actions=[action.to_view_data() for action in models.SchAction.objects.filter(trigger=trigger)]
        )
        for trigger in models.SchTrigger.objects.filter(location=_id, type=_trigger_type)
    ])


def set_enabled(request):
    _id = int(request.GET.get('id'))
    _enabled = request.GET.get('enabled') == 'true'
    model = models.SchLocation.objects.get(id=_id)
    model.enabled = _enabled
    model.save()
    return Success(_enabled)


def status(request):
    _loc_id = int(request.GET.get('id'))
    return Success(dict(
        actions={data['name']: data['commands'] for data in models.SchAction.actions(_loc_id)},
        enabled=models.SchLocation.objects.get(id=_loc_id).enabled
    ))


def set_day(request):
    y = int(request.GET.get('year'))
    m = int(request.GET.get('month'))
    d = int(request.GET.get('day'))

    classes = []

    date = datetime.date(y, m, d)

    if date == datetime.date.today():
        classes.append('current')

    try:
        models.Holiday.objects.create(date=date)
        classes.append('weekend')
    except:
        models.Holiday.objects.get(date=date).delete()
        classes.append('work')

    return Success(' '.join(classes))


def set_time(request):
    _loc_id = int(request.GET.get('location'))
    _tr_id = request.GET.get('trigger')
    _type = request.GET.get('type')
    _time = request.GET.get('time')

    if _tr_id:
        model = models.SchTrigger.objects.get(id=int(_tr_id), type=_type)
        model.time = _time
        model.save()
    else:
        model = models.SchTrigger.objects.create(time=_time, location=models.SchLocation.objects.get(id=_loc_id), type=_type)

    return Success(dict(id=model.id, time=model.time))


def remove_trigger(request):
    models.SchTrigger.objects.get(id=int(request.GET.get('trigger'))).delete()
    return Success()


def remove_action(request):
    models.SchAction.objects.get(id=int(request.GET.get('action'))).delete()
    return Success()


def set_action(request):
    return Success(
        models.SchAction.from_view_data(
            loc_id=int(request.GET.get('location')),
            tr_id=int(request.GET.get('trigger')),
            target=int(request.GET.get('target')),
            act_id=request.GET.get('action'),
            index=int(request.GET.get('index')),
            value=request.GET.get('value')
        ).id
    )
